
#' Once the k-means heuristic has been applied, we can extract any
#' gene partition from all those that were obtained across the k-means
#' iterations by using this function.
#' @param expr.data.file Full path to the expression data fine in rds format
#' @param beta the smoothing parameter used (needed to create eigengenes)
#' @param partitions.file The partitions file as generated by \code{applykM2WGCNA}
#' @param mgg The number of genes below which grey module won't be considered as
#' part of the networks and genes will be discarded
#' @param index The iteration in which the partition we want to recover was created
#' @return A WGCNA like object with \code{moduleColors} and \code{MEs} components.
#' @importFrom WGCNA moduleEigengenes
#' @export
genNetFromPartition <- function(expr.data.file,
                                beta,
                                partitions.file,
                                mgg,
                                index=-1){

  parts <- readRDS(partitions.file)

  if(index < 0)
    index = length(parts)

  colors = unique(names(parts[[1]]))
  col.number = unique(parts[[1]])

  if(typeof(expr.data.file) == "character")
    expr.data = readRDS(expr.data.file)
  else
    expr.data = expr.data.file

  new.net <- NULL
  if(index == 1){
    new.net$moduleLabels = parts[[index]]
    new.net$moduleColors = names(parts[[index]])
    names(new.net$moduleColors) = colnames(expr.data)
    names(new.net$moduleLabels) = colnames(expr.data)

  }else{
    new.net$moduleLabels = parts[[index]]
    new.net$moduleColors = colors[match(parts[[index]],col.number)]
    names(new.net$moduleColors) = colnames(expr.data)
    names(new.net$moduleLabels) = colnames(expr.data)

  }

  #If there are some grey genes as NA, add them again
  new.net$moduleColors[is.na(new.net$moduleColors)] = "grey"

  if(sum(new.net$moduleColors == "grey") >= mgg)
    new.net$MEs <- moduleEigengenes(expr.data,new.net$moduleColors,softPower=beta, excludeGrey=F)$eigengenes
  else
    new.net$MEs <- moduleEigengenes(expr.data,new.net$moduleColors,softPower=beta, excludeGrey=T)$eigengenes

  return(new.net)
}
